==> tine20-inventory_2019.12.5.tar.bz2: Inventory/js/Inventory-lang-sv_SE-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Inventory **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Inventory'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-01-21 20:56+0000\nLast-Translator: S P <sebbe088@gmail.com>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: sv_SE\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Inventory item, Inventory items"
: [
  ""
 ,""

]
, "Inventory item list, Inventory item lists"
: [
  ""
 ,""

]
, "Name"
: "Benämning"

, "Status"
: ""

, "Inventory ID"
: "Lager ID"

, "Description"
: "Beskrivning"

, "Location"
: ""

, "Invoice date"
: "Fakturadatum"

, "Invoice"
: "Faktura"

, "Price"
: "Pris"

, "Cost Center"
: "Kostnadsställe"

, "Warranty"
: "Garanti"

, "Item added"
: ""

, "Item removed"
: "Objekt borttaget"

, "Deprecate"
: "Avskrivning"

, "The active number must be less than or equal total number."
: ""

, "General"
: ""

, "ID"
: "ID"

, "Enter description"
: "Ange beskrivning"

, "Added"
: ""

, "Removed"
: ""

, "Total number"
: ""

, "Available number"
: ""

, "Accounting"
: ""

, "Cost center"
: "Kostnadsställe"

, "Depreciate"
: ""

, "Default Inventory Item Container"
: ""

, "The default container for new items"
: ""

, "Inventory Status Available"
: ""

, "Possible status."
: ""

, "ordered"
: "beställd"

, "available"
: ""

, "defect"
: "defekt"

, "missing"
: ""

, "removed"
: ""

, "unknown"
: "okänd"

, "Inventory CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Items imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "All Inventory Items"
: "Alla lagerobjekt"

, "All existing Inventory Items"
: "Alla befintliga lagerobjekt"

, "Inventory"
: "Lager"

, "Inventory item"
: ""

, "Inventory item list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-inventory_2020.08.8.tar.bz2: Inventory/js/Inventory-lang-sv_SE-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Inventory **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Inventory'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-01-21 20:56+0000\nLast-Translator: S P <sebbe088@gmail.com>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nLanguage: sv_SE\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Default Inventory Item Container"
: ""

, "The default container for new items"
: ""

, "The active number must be less than or equal total number."
: ""

, "General"
: ""

, "ID"
: "ID"

, "Name"
: "Benämning"

, "Description"
: "Beskrivning"

, "Enter description"
: "Ange beskrivning"

, "Location"
: ""

, "Added"
: ""

, "Warranty"
: "Garanti"

, "Removed"
: ""

, "Total number"
: ""

, "Available number"
: ""

, "Status"
: ""

, "Accounting"
: ""

, "Price"
: "Pris"

, "Cost center"
: "Kostnadsställe"

, "Invoice"
: "Faktura"

, "Invoice date"
: "Fakturadatum"

, "Depreciate"
: ""

, "All Inventory Items"
: "Alla lagerobjekt"

, "All existing Inventory Items"
: "Alla befintliga lagerobjekt"

, "Inventory"
: "Lager"

, "Inventory Status Available"
: ""

, "Possible status."
: ""

, "ordered"
: "beställd"

, "available"
: ""

, "defect"
: "defekt"

, "missing"
: ""

, "removed"
: ""

, "unknown"
: "okänd"

, "Inventory item, Inventory items"
: [
  ""
 ,""

]
, "Inventory item list, Inventory item lists"
: [
  ""
 ,""

]
, "Inventory ID"
: "Lager ID"

, "Cost Center"
: "Kostnadsställe"

, "Item added"
: ""

, "Item removed"
: "Objekt borttaget"

, "Inventory CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Items imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""


, "Inventory item"
: ""

, "Inventory item list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
